==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard.mime.encryptor/src/com/openexchange/guard/mime/encryptor/exceptions/MimeEncryptorExceptionExceptionMessages.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.mime.encryptor.exceptions;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link MimeEncryptorExceptionExceptionMessages}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public final class MimeEncryptorExceptionExceptionMessages implements LocalizableStrings {

    public static final String SEND_EMAIL_ERROR = "Unable to send email to '%1$s'";

    public static final String SEND_NOT_AUTHORIZED = "User does not have email encryption enabled and is not authorized to send.";

    public static final String SEND_UNABLE_FIND_KEYS = "Unable to find keys for all recipients";

    public static final String PASSWORD_BAD = "Password is missing or authentication bad";

    public static final String PROBLEM_DECODING_ENCRYPTED_ATTACHMENT = "There was a problem decoding the encrypted attachment";

    private MimeEncryptorExceptionExceptionMessages() {}
}

==> open-xchange-guard_2.10.1.orig.tar.bz2: open-xchange-guard-2.10.1/com.openexchange.guard.mime.encryptor/src/com/openexchange/guard/mime/encryptor/exceptions/MimeEncryptorExceptionExceptionMessages.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.mime.encryptor.exceptions;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link MimeEncryptorExceptionExceptionMessages}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public final class MimeEncryptorExceptionExceptionMessages implements LocalizableStrings {

    // Unable to send an email to email address
    public static final String SEND_EMAIL_ERROR = "Unable to send email to '%1$s'";

    // User does not have email encryption enabled, not authorized to send a new encrypted email
    public static final String SEND_NOT_AUTHORIZED = "User does not have email encryption enabled and is not authorized to send.";

    // Unable to find encryption keys for all recipients
    public static final String SEND_UNABLE_FIND_KEYS = "Unable to find keys for all recipients";

    // No recipients specified, so can't encrypt
    public static final String NO_RECIPIENTS = "Unable to encrypt, no recipients";

    // Unknown email body type.  Failed to encrypt
    public static final String UNKONWN_BODY_TYPE = "Unable to encrypt due to unknown body type";

    // Password missing or authentication invalid
    public static final String PASSWORD_BAD = "Password is missing or authentication invalid";

    // Problem decrypting the attachment
    public static final String PROBLEM_DECODING_ENCRYPTED_ATTACHMENT = "There was a problem decoding the encrypted attachment";

    // When a guest replies, they can only reply to the sender and people cc'd in the email.  They cannot add recipients.  One or more extra recipients found and that isn't allowed.  Chain refers to the group of people originally in the email
    public static final String RECIPIENT_NOT_IN_CHAIN = "One or more of the recipients was not in the original email chain, '%1$s";

    // The message is missing some of the required security information.  Without this, we can't be sure the message is intact and hasn't been altered.
    public static final String MISSING_MDC = "Unable to decrypt this message.  It is missing Modification Detection Code, and the system is unable to verify the integrity of the message.";

    private MimeEncryptorExceptionExceptionMessages() {}
}
